@@ -23,10 +23,12 @@ def actions_renderer(widget, data):
     kw = dict(class_='dict_actions')
     return tag('div', *actions, **kw)
 
+
+factory.register(
+    'dict_actions',
+    edit_renderers=[actions_renderer])
+
 factory.doc['widget']['dict_actions'] = UNSET # dont document internal widget
-factory.register('dict_actions',
-                 [],
-                 [actions_renderer])
 
 
 def dict_builder(widget, factory):
@@ -64,7 +66,7 @@ def dict_builder(widget, factory):
     table['body'] = factory('tbody', props={'structural': True})
 
 
-def dict_renderer(widget, data):
+def dict_edit_renderer(widget, data):
     static = widget.attrs['static']
     table = widget['table']
     table.attrs['id'] = 'dictwidget_%s.entry' % widget.dottedpath
@@ -169,17 +171,38 @@ def dict_extractor(widget, data):
                     raise_extraction_error(widget)
     return ret
 
+
+def dict_display_renderer(widget, data):
+    value = data.value
+    if not value:
+        value = dict()
+    values = list()
+    for key, val in value.items():
+        values.append(data.tag('dt', key) + data.tag('dd', val))
+    head = u''
+    if widget.attrs.get('head'):
+        head = '%s: %s' % (widget.attrs['head']['key'],
+                           widget.attrs['head']['value'])
+        head = data.tag('h5', head)
+    return head + data.tag('dl', *values)
+
+
+factory.register(
+    'dict',
+    extractors=[compound_extractor, dict_extractor],
+    edit_renderers=[dict_edit_renderer, compound_renderer],
+    display_renderers=[dict_display_renderer],
+    builders=[dict_builder])
+
 factory.doc['widget']['dict'] = \
 """Add-on widget `yafowil.widget.dict 
 <http://github.com/bluedynamics/yafowil.widget.dict/>`_.
 """
 
 factory.defaults['dict.default'] = odict()
+
 factory.defaults['dict.static'] = False
+
 factory.defaults['dict.error_class'] = 'error'
-factory.defaults['dict.message_class'] = 'errormessage'
-factory.register('dict',
-                 [compound_extractor, dict_extractor],
-                 [dict_renderer, compound_renderer],
-                 [],
-                 [dict_builder])
\ No newline at end of file
+
+factory.defaults['dict.message_class'] = 'errormessage'
\ No newline at end of file
